@echo off

set BUILD_IMAGE=bx2000.f9
set BUILD_ARCHIVE_PREFIX=motherboard_bios_ga-bx2000_f9
for /f "usebackq tokens=1,2 delims==" %%i in (`wmic os get LocalDateTime /value 2^>nul`) do if /%%i/==/LocalDateTime/ set BUILD_DATE=%%j
set BUILD_DATE=%BUILD_DATE:~0,8%

set WINRAR_LOCATION="C:\Program Files\WinRAR\WinRAR.exe"

pushd "%~dp0"
if errorlevel 1 goto exit

if exist %WINRAR_LOCATION% (set CREATE_ARCHIVE=1) else (set CREATE_ARCHIVE=0)

echo.
echo ===============================================================================
echo Cleaning up
echo ===============================================================================
echo.
del work\* /Q
del ..\%BUILD_ARCHIVE_PREFIX%_*.zip

echo.
echo ===============================================================================
echo Concatenating microcodes
echo ===============================================================================
echo.
copy /b microcode\*.bin work\CPUCODE.BIN
if errorlevel 1 goto exit

echo.
echo ===============================================================================
echo Compressing microcodes
echo ===============================================================================
echo.
tool\lha.exe a work\temp.lzh -o2 -h1 work\CPUCODE.BIN
if errorlevel 1 goto exit
del work\CPUCODE.BIN
ren work\temp.lzh CPUCODE.BIN

echo.
echo ===============================================================================
echo Fixing microcode module
echo ===============================================================================
echo.
tool\ApplyPat.exe patch\module_cpucode.pat work\CPUCODE.BIN
if errorlevel 1 goto exit

echo.
echo ===============================================================================
echo Compressing logo
echo ===============================================================================
echo.
copy logo\dbios.bmp work>nul
if errorlevel 1 goto exit
tool\lha.exe a work\temp.lzh -o2 -h1 work\dbios.bmp
if errorlevel 1 goto exit
del work\dbios.bmp
ren work\temp.lzh dbios.bmp

echo.
echo ===============================================================================
echo Fixing logo module
echo ===============================================================================
echo.
tool\ApplyPat.exe patch\module_dbios.pat work\dbios.bmp
if errorlevel 1 goto exit

echo.
echo ===============================================================================
echo Reassembling and fixing BIOS image
echo ===============================================================================
echo.
copy original\%BUILD_IMAGE% work>nul
if errorlevel 1 goto exit
tool\ApplyPat.exe patch\image.pat work\%BUILD_IMAGE%
if errorlevel 1 goto exit

echo.
echo ===============================================================================
echo Cleaning up
echo ===============================================================================
echo.
copy work\%BUILD_IMAGE% .. /Y>nul
if errorlevel 1 goto exit
del work\* /Q

if %CREATE_ARCHIVE%==1 (
    echo.
    echo ===============================================================================
    echo Building archive
    echo ===============================================================================
    echo.
    %WINRAR_LOCATION% a ..\%BUILD_ARCHIVE_PREFIX%_%BUILD_DATE%.zip ..\%BUILD_IMAGE% ..\build
)

:exit

popd

set BUILD_IMAGE=
set BUILD_ARCHIVE_PREFIX=
set BUILD_DATE=

set WINRAR_LOCATION=

set CREATE_ARCHIVE=
